Introduction
============

`RStudio <https://www.rstudio.com/>`_ is an Integrated Development Environment for
the R programming language.

This Ansible role can be used to deploy RStudio Server, which is RStudio
implemented as a web application accessible in a browser.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.3.0``. To install it, run:

.. code-block:: yaml

   ansible-galaxy install debops.rstudio_server

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
